@@ -1,5 +1,7 @@
 #[cfg(feature = "non_critical_lints")]
 use crate::rules::non_critical_lints::no_console::NoConsoleConfig;
+#[cfg(feature = "non_critical_lints")]
+use crate::rules::non_critical_lints::prefer_regex_literals::PreferRegexLiteralsConfig;
 use serde::{Deserialize, Serialize};
 use std::fmt::Debug;
 
@@ -41,6 +43,10 @@ pub struct LintConfig {
     #[serde(default)]
     pub no_console: RuleConfig<NoConsoleConfig>,
 
+    #[cfg(feature = "non_critical_lints")]
+    #[serde(default)]
+    pub prefer_regex_literals: RuleConfig<PreferRegexLiteralsConfig>,
+
     #[cfg(feature = "non_critical_lints")]
     #[serde(default)]
     pub no_alert: RuleConfig<()>,
