@@ -13,6 +13,7 @@ pub(crate) mod non_critical_lints {
     pub mod no_alert;
     pub mod no_console;
     pub mod no_debugger;
+    pub mod prefer_regex_literals;
 }
 
 #[cfg(feature = "non_critical_lints")]
@@ -54,6 +55,13 @@ pub fn all(lint_params: LintParams) -> Vec<Box<dyn Rule>> {
         ));
 
         rules.extend(no_debugger::no_debugger(&lint_config.no_debugger));
+
+        rules.extend(prefer_regex_literals::prefer_regex_literals(
+            program,
+            &lint_config.prefer_regex_literals,
+            top_level_ctxt,
+            es_version,
+        ));
     }
 
     rules
